package com.yanzhu.jh.work.controller;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.core.text.Convert;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.enums.SysRoleEnum;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.system.service.ISysDeptService;
import com.yanzhu.jh.project.domain.SurProjectUnitInfo;
import com.yanzhu.jh.project.service.ISurProjectUnitInfoService;
import com.yanzhu.jh.work.domain.WorkTrain;
import com.yanzhu.jh.work.service.IWorkTrainService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 演练培训Controller
 *
 * @author JiangYuQi
 * @date 2023-08-09
 */
@RestController
@RequestMapping("/work/emergencyDrill")
public class EmergencyDrillController extends BaseController
{
    @Autowired
    private IWorkTrainService workTrainService;

    @Autowired
    private ISysDeptService sysDeptService;

    @Autowired
    private ISurProjectUnitInfoService surProjectUnitInfoService;

    /**
     * 查询演练培训列表
     */
    @PreAuthorize("@ss.hasPermi('work:emergencyDrill:list')")
    @GetMapping("/list")
    public TableDataInfo list(WorkTrain workTrain)
    {
        startPage();
        workTrain.setNowRole(Convert.toStr(getUserFirstRole()));
        if(SysRoleEnum.ZGS.getCode().equals(workTrain.getNowRole())){
            workTrain.setNowDept(Convert.toStr(sysDeptService.getZGSDeptId(getDeptId())));
        }else{
            workTrain.setNowDept(Convert.toStr(getDeptId()));
        }
        workTrain.setNowUser(Convert.toStr(getUserId()));
        workTrain.setNowUserName(getUsername());
        List<WorkTrain> list = workTrainService.selectWorkTrainList(workTrain);
        return getDataTable(list);
    }

    /**
     * 导出演练培训列表
     */
    @PreAuthorize("@ss.hasPermi('work:emergencyDrill:export')")
    @Log(title = "演练培训", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, WorkTrain workTrain)
    {
        List<WorkTrain> list = workTrainService.selectWorkTrainList(workTrain);
        ExcelUtil<WorkTrain> util = new ExcelUtil<WorkTrain>(WorkTrain.class);
        util.exportExcel(response, list, "演练培训数据");
    }

    /**
     * 获取演练培训详细信息
     */
    @PreAuthorize("@ss.hasPermi('work:emergencyDrill:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(workTrainService.selectWorkTrainById(id));
    }

    /**
     * 新增演练培训
     */
    @PreAuthorize("@ss.hasPermi('work:emergencyDrill:add')")
    @Log(title = "演练培训", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody WorkTrain workTrain)
    {
        return toAjax(workTrainService.insertWorkTrain(workTrain));
    }

    /**
     * 修改演练培训
     */
    @PreAuthorize("@ss.hasPermi('work:emergencyDrill:edit')")
    @Log(title = "演练培训", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody WorkTrain workTrain)
    {
        return toAjax(workTrainService.updateWorkTrain(workTrain));
    }

    /**
     * 删除演练培训
     */
    @PreAuthorize("@ss.hasPermi('work:emergencyDrill:remove')")
    @Log(title = "演练培训", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(workTrainService.deleteWorkTrainByIds(ids));
    }

    /**
     * 查询协同演练部门列表
     */
    @PreAuthorize("@ss.hasPermi('work:emergencyDrill:query')")
    @GetMapping("/projectUnitList")
    public AjaxResult projectUnitList(SurProjectUnitInfo surProjectUnitInfo)
    {
        return success(surProjectUnitInfoService.selectSurProjectUnitInfoList(surProjectUnitInfo));
    }

}
